.. Python FTR documentation master file, created by
   sphinx-quickstart on Tue Mar 10 09:11:24 2015.

Welcome to Python FTR's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   config
   extractor
   process

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

